package ca.canadapost.cpcdp.ncshipping;

import ca.canadapost.cpcdp.ncshipping.stub.ncshipment.*;
import org.apache.cxf.endpoint.Client;
import org.apache.cxf.frontend.ClientProxy;
import ca.canadapost.cpcdp.ncshipping.util.ClientUtil;

import javax.xml.ws.BindingProvider;
import javax.xml.ws.soap.SOAPFaultException;
import java.io.FileInputStream;
import java.util.Map;
import java.util.Properties;


/**
 * Sample code for the GetNonContractShipment Canada Post service.
 * <p>
 * The GetNonContractShipment service is used to retrieve the label and receipt 
 * information for a previously created shipment. Typically used after a 
 * Get Non-Contract Shipments call.  
 * <p>
 * This sample is configured to access the Developer Program sandbox environment. 
 * Use your development key username and password for the web service credentials.
 */

public class GetNCShipmentClient {

    // Main class for local testing only
    public static void main(String[] args) {    	
        try {
			// Your username, password and customer number are imported from the following file: CPCWS_SOAP_NCShipping_Java_Samples/user.properties
            Map<String, String> userProperties = ClientUtil.getUserProperties("user.properties");
            String username = userProperties.get("username");
            String password = userProperties.get("password");
            String mailedBy = userProperties.get("mailedBy");

            NCShipmentService service = new NCShipmentService();
            NCShipmentPortType port = service.getNCShipmentPort();

            //set endpoint
            Map ctx = ((BindingProvider) port).getRequestContext();
            ctx.put(BindingProvider.ENDPOINT_ADDRESS_PROPERTY, "https://ct.soa-gw.canadapost.ca/rs/soap/ncshipment/v4");

            //wss4j interceptor -  add UsernameToken to soap header
            Client client = ClientProxy.getClient(port);
            client.getOutInterceptors().add(ClientUtil.getUsernameTokenInterceptor(username, password));
    		
        	//create request
        	GetNonContractShipmentRequest request = new GetNonContractShipmentRequest();
            request.setLocale("FR");
            request.setMailedBy(mailedBy);
        	request.setShipmentId("522121393172629625");

        	// Execute Request
        	GetNonContractShipmentResponse response = port.getNCShipment(request);

            // Retrieve values from response object
            if (response.getMessages() == null) {
                NonContractShipmentInfoType nonContractShipmentInfoType = response.getNonContractShipmentInfo();
            	System.out.println("Shipment Id: " + nonContractShipmentInfoType.getShipmentId());
                for(ArtifactType a : nonContractShipmentInfoType.getArtifacts().getArtifact()){
                    System.out.println("Artifact Type: " + a.getType());
                    System.out.println("Artifact Id: " + a.getArtifactId());
                    System.out.println("Page Index: " + a.getPageIndex());
                    System.out.println();
                }
            } else {
                // Assume Error
                for(Messages.Message m : response.getMessages().getMessage()){
                    System.out.println("Error Code: " + m.getCode());
                    System.out.println("Error Message: " + m.getDescription());
                }
            }                                    
        }
        catch (SOAPFaultException e) {
            System.out.println("Fault Code: " + e.getFault().getFaultCode());
            System.out.println("Fault Reason: " + e.getFault().getFaultString());
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
